[xoops-cvslog 4608] CVS update: xoops2jp/html/modules/base/kernel

Back to archive index

NobuNobu nobun****@users*****
2006年 9月 25日 (月) 10:27:04 JST


Index: xoops2jp/html/modules/base/kernel/Legacy_AdminModuleController.class.php
diff -u xoops2jp/html/modules/base/kernel/Legacy_AdminModuleController.class.php:1.1.2.4 xoops2jp/html/modules/base/kernel/Legacy_AdminModuleController.class.php:1.1.2.5
--- xoops2jp/html/modules/base/kernel/Legacy_AdminModuleController.class.php:1.1.2.4	Fri Aug 18 18:10:28 2006
+++ xoops2jp/html/modules/base/kernel/Legacy_AdminModuleController.class.php	Mon Sep 25 10:27:04 2006
@@ -1,7 +1,7 @@
 <?php
 /**
  * @package Legacy
- * @version $Id: Legacy_AdminModuleController.class.php,v 1.1.2.4 2006/08/18 09:10:28 minahito Exp $
+ * @version $Id: Legacy_AdminModuleController.class.php,v 1.1.2.5 2006/09/25 01:27:04 nobunobu Exp $
  */
 
 if (!defined('XOOPS_ROOT_PATH')) exit();
@@ -107,7 +107,7 @@
 		$dmy =& $module->getInfo();
 
 		//
 		// Load admin menu, and add preference menu by own judge.
 		//
 		$module->loadAdminMenu();
 		if ($module->getVar('hasnotification')
@@ -119,6 +119,12 @@
 					'absolute' => true);
 		}
 		
+		if ($module->hasHelp()) {
+			$helpUrl = XOOPS_MODULE_URL . '/base/admin/index.php?action=Help&amp;dirname=' . $module->getVar('dirname');
+			$module->adminmenu[] = array('link' => $helpUrl,
+			                              'title' => _HELP,
+			                              'absolute' => true);
+		}
 		$this->mModuleObject =& $module;
 	}
 
@@ -107,7 +107,7 @@
 
 		//
-		// Load admin menu, and add preference menu by own judge.
+		// Load admin menu, and add preference and help menu by own judge.
 		//
 		$module->loadAdminMenu();


xoops-cvslog メーリングリストの案内
Back to archive index